@@ -128,6 +128,9 @@ CV_PY_TO_ENUM(HistCompMethods)
 CV_PY_FROM_ENUM(HoughModes)
 CV_PY_TO_ENUM(HoughModes)
 
+CV_PY_FROM_ENUM(ImageMetadataType)
+CV_PY_TO_ENUM(ImageMetadataType)
+
 CV_PY_FROM_ENUM(ImreadModes)
 CV_PY_TO_ENUM(ImreadModes)
 
@@ -152,6 +155,9 @@ CV_PY_TO_ENUM(ImwriteJPEGSamplingFactorParams)
 CV_PY_FROM_ENUM(ImwritePAMFlags)
 CV_PY_TO_ENUM(ImwritePAMFlags)
 
+CV_PY_FROM_ENUM(ImwritePNGFilterFlags)
+CV_PY_TO_ENUM(ImwritePNGFilterFlags)
+
 CV_PY_FROM_ENUM(ImwritePNGFlags)
 CV_PY_TO_ENUM(ImwritePNGFlags)
 
